@@ -37,7 +37,7 @@ pub trait Deqp {
         tests: I,
     ) -> Result<Vec<RunnerResult>>;
 
-    fn see_more(&self, _caselist_state: &CaselistState) -> String {
+    fn see_more(&self, _name: &str, _caselist_state: &CaselistState) -> String {
         "".to_string()
     }
 
@@ -70,7 +70,7 @@ pub trait Deqp {
                 "Test {}: {}: {}",
                 &result.name,
                 status,
-                self.see_more(&caselist_state)
+                self.see_more(&result.name, &caselist_state)
             );
         }
 
@@ -132,7 +132,7 @@ pub trait Deqp {
             let test = test.as_ref().clone();
             if self.skip_test(format!("{}{}", self.prefix(), &test.name()).as_str()) {
                 caselist_results.push(RunnerResult {
-                    test: test.name().to_owned(),
+                    test: format!("{}{}", self.prefix(), test.name()),
                     status: RunnerStatus::Skip,
                     duration: Default::default(),
                     subtest: false,
@@ -175,7 +175,7 @@ pub trait Deqp {
                     error!(
                         "Failure getting run results: {:#} ({})",
                         e,
-                        self.see_more(&caselist_state)
+                        self.see_more("", &caselist_state)
                     );
 
                     for test in remaining_tests {
@@ -484,7 +484,7 @@ impl Deqp for DeqpCommand {
             if line.contains("ERROR: LeakSanitizer: detected memory leaks") {
                 error!(
                     "deqp-runner: Leak detected, marking caselist as failed ({})",
-                    self.see_more(caselist_state)
+                    self.see_more("", caselist_state)
                 );
                 for result in deqp_results.iter_mut() {
                     result.status = DeqpStatus::Fail;
@@ -498,7 +498,9 @@ impl Deqp for DeqpCommand {
             let status = self.translate_result(&result, &caselist_state);
 
             if !status.is_success() {
-                if let Err(e) = self.try_extract_qpa(&result.name, &qpa_path) {
+                if let Err(e) =
+                    self.try_extract_qpa(result.name.trim_start_matches(&self.prefix), &qpa_path)
+                {
                     warn!("Failed to extract QPA resuls: {}", e)
                 }
             }
@@ -529,7 +531,7 @@ impl Deqp for DeqpCommand {
         Ok(results)
     }
 
-    fn see_more(&self, caselist_state: &CaselistState) -> String {
+    fn see_more(&self, _name: &str, caselist_state: &CaselistState) -> String {
         // This is the same as run() did, so we should be safe to unwrap.
         let qpa_path = self.output_dir.join(
             format!(
@@ -584,13 +586,9 @@ impl Deqp for PiglitCommand {
             _ => panic!("Invalid case"),
         };
 
-        let log_path = self.output_dir.join(
-            format!(
-                "c{}.r{}.log",
-                caselist_state.caselist_id, caselist_state.run_id
-            )
-            .as_str(),
-        );
+        let log_path = self
+            .output_dir
+            .join(format!("piglit.{}.log", test.name).as_str());
 
         let mut command = Command::new(bin_path.join(Path::new(&test.binary)));
         command
@@ -732,14 +730,10 @@ impl Deqp for PiglitCommand {
         Ok(results)
     }
 
-    fn see_more(&self, caselist_state: &CaselistState) -> String {
-        let log_path = self.output_dir.join(
-            format!(
-                "c{}.r{}.log",
-                caselist_state.caselist_id, caselist_state.run_id
-            )
-            .as_str(),
-        );
+    fn see_more(&self, test_name: &str, _caselist_state: &CaselistState) -> String {
+        let log_path = self
+            .output_dir
+            .join(format!("piglit.{}.log", test_name).as_str());
         format!("See {:?}", log_path)
     }
 
