@@ -657,10 +657,44 @@ fn suite_prefix_test() {
         results.tests["variant1-dEQP-GLES2.test.p.1"].status,
         RunnerStatus::Pass
     );
+    assert_eq!(
+        results.tests["variant1-dEQP-GLES2.test.p.2"].status,
+        RunnerStatus::Skip
+    );
     assert_eq!(
         results.tests["variant2-dEQP-GLES2.test.p.1"].status,
         RunnerStatus::UnexpectedPass
     );
+}
 
-    assert!(!results.tests.contains_key("variant1-dEQP-GLES2.test.p.2"));
+#[test]
+fn suite_prefix_skips() {
+    let mut deqp1 = DeqpMock::new();
+    deqp1.with_cases(vec!["dEQP-GLES2.test.p.1"]);
+    deqp1.with_skips("dEQP-GLES2.*.p.1");
+    let mut deqp2 = DeqpMock::new();
+    deqp2.with_cases(vec!["dEQP-GLES2.test.p.1"]);
+    deqp2.with_skips("dEQP-GLES2.*.p.1");
+    deqp2.with_prefix("variant-");
+
+    let results = DeqpSuite::new()
+        .with_deqp(deqp1)
+        .with_deqp(deqp2)
+        .run()
+        .unwrap();
+    assert_eq!(Some(0), results.status.code());
+    assert!(results.stdout.contains("Skip: 2"));
+
+    let results = results.results.unwrap();
+    assert_eq!(results.result_counts.skip, 2);
+    assert_eq!(results.result_counts.fail, 0);
+
+    assert_eq!(
+        results.tests["dEQP-GLES2.test.p.1"].status,
+        RunnerStatus::Skip
+    );
+    assert_eq!(
+        results.tests["variant-dEQP-GLES2.test.p.1"].status,
+        RunnerStatus::Skip
+    );
 }
